@@ -62,7 +62,7 @@ def rot2(theta: float, unit: str = "rad") -> SO2Array:
         >>> rot2(0.3)
         >>> rot2(45, 'deg')
     """
-    theta = smb.getunit(theta, unit)
+    theta = smb.getunit(theta, unit, dim=0)
     ct = smb.sym.cos(theta)
     st = smb.sym.sin(theta)
     # fmt: off
@@ -718,7 +718,7 @@ def tradjoint2(T):
         >>> tr2adjoint2(T)
 
     :Reference:
-        - Robotics, Vision & Control for Python, Section 3, P. Corke, Springer 2023.
+        - Robotics, Vision & Control for Python, Section 3.1, P. Corke, Springer 2023.
         - `Lie groups for 2D and 3D Transformations <http://ethaneade.com/lie.pdf>_
 
     :SymPy: supported
@@ -762,7 +762,7 @@ def tr2jac2(T: SE2Array) -> R3x3:
         >>> T = trot2(0.3, t=[4,5])
         >>> tr2jac2(T)
 
-    :Reference: Robotics, Vision & Control: Second Edition, P. Corke, Springer 2016; p65.
+    :Reference: Robotics, Vision & Control for Python, Section 3.1, P. Corke, Springer 2023.
     :SymPy: supported
     """
 
@@ -774,9 +774,17 @@ def tr2jac2(T: SE2Array) -> R3x3:
     return J
 
 
-def trinterp2(
-    start: Union[SE2Array, None], end: SE2Array, s: float
-) -> Union[SO2Array, SE2Array]:
+@overload
+def trinterp2(start: Optional[SO2Array], end: SO2Array, s: float) -> SO2Array:
+    ...
+
+
+@overload
+def trinterp2(start: Optional[SE2Array], end: SE2Array, s: float) -> SE2Array:
+    ...
+
+
+def trinterp2(start, end, s):
     """
     Interpolate SE(2) or SO(2) matrices
 
@@ -971,15 +979,12 @@ def points2tr2(p1: NDArray, p2: NDArray) -> SE2Array:
     # compute moment matrix
     M = np.dot(p2_centered, p1_centered.T)
 
-    # get singular value decomposition of the cross covariance matrix
+    # get singular value decomposition of the cross covariance matrix, use Umeyama trick
     U, W, VT = np.linalg.svd(M)
 
     # get rotation between the two point clouds
-    R = U @ VT
-    # special reflection case
-    if np.linalg.det(R) < 0:
-        VT[-1, :] *= -1
-        R = VT.T @ U.T
+    s = [1, np.linalg.det(U) * np.linalg.det(VT)]
+    R = U @ np.diag(s) @ VT
 
     # get the translation
     t = p2_centroid - R @ p1_centroid
@@ -1414,7 +1419,7 @@ if _matplotlib_exists:
             pass
 
         anim.trplot2(T, **kwargs)
-        anim.run(**kwargs)
+        return anim.run(**kwargs)
 
 
 if __name__ == "__main__":  # pragma: no cover
